@@ -2,7 +2,7 @@ package Sim::OPT;
 # Copyright (C) 2008-2018 by Gian Luca Brunetti and Politecnico di Milano.
 # This is Sim::OPT, a program managing building performance simulation programs for performing optimization by overlapping block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
-$VERSION = '0.443';
+$VERSION = '0.445';
 use v5.14;
 # use v5.20;
 use Exporter;
@@ -2049,10 +2049,10 @@ sub exe
 	my %to = %{ $d{to} }; #say $tee "IN12 EXE \%to : " . dump( %to );
 	my $countvar = $d{countvar}; #say $tee "IN12 EXE \$countvar : " . dump( $countvar );
 	my $countstep = $d{countstep}; #say $tee "IN12 EXE \$countstep : " . dump( $countstep );
-	my %carrier = %{ $d{carrier} }; say $tee "IN exe \%carrier " . dump( \%carrier );
-	my %varnums = %{ $d{varnums} }; say $tee "IN exe \%varnums " . dump( \%varnums );
-	my $file = $dowhat{file}; say $tee "IN exe \$file " . dump( $file );
-	my $mypath = $dowhat{mypath}; say $tee "IN exe \$mypath " . dump( $mypath );
+	my %carrier = %{ $d{carrier} }; #say $tee "IN exe \%carrier " . dump( \%carrier );
+	my %varnums = %{ $d{varnums} }; #say $tee "IN exe \%varnums " . dump( \%varnums );
+	my $file = $dowhat{file}; #say $tee "IN exe \$file " . dump( $file );
+	my $mypath = $dowhat{mypath}; #say $tee "IN exe \$mypath " . dump( $mypath );
 	my @blockelts = @{ $d{blockelts} }; #say $tee "IN DEFFILES \@blockelts : " . dump( @blockelts );
 	my @sourceblockelts = @{ $d{blockelts} }; #say $tee "IN DEFFILES \@sourceblockelts : " . dump( @blockelts );
 	my @blocks = @{ $d{blocks} }; #say $tee "IN DEFFILES \@blocks : " . dump( @blocks );
